import { ISODateTimeString } from "polar-shared/src/metadata/ISODateTimeStrings";
import { ISpacedRep, Rating, StageCounts, Task } from "polar-spaced-repetition-api/src/scheduler/S2Plus/S2Plus";
import { Duration, DurationMS } from "polar-shared/src/util/TimeDurations";
export interface CalculatedTaskReps<A> {
    readonly taskReps: ReadonlyArray<TaskRep<A>>;
    readonly stageCounts: StageCounts;
}
export declare class TasksCalculator {
    static LAPSE_INIT_INTERVAL: Duration;
    static LAPSE_REVIEW_NEW_INTERVAL_FACTOR: number;
    static LAPSE_REVIEW_NEW_INTERVAL_MIN: Duration;
    static calculate<A>(opts: CalculateOpts<A>): Promise<CalculatedTaskReps<A>>;
    private static computeAgeFromReviewedAt;
    static computeAge(current: ISpacedRep): number;
    static computeNextSpacedRep<A>(taskRep: TaskRep<A>, rating: Rating): ISpacedRep;
    static createInitialSpacedRep<A>(task: Task<A>, reviewedAt?: ISODateTimeString): ISpacedRep;
    static createInitialLearningState<A>(task: Task<A>): TaskRep<A>;
}
export interface OptionalTaskRepResolver<A> {
    (task: Task<A>): Promise<TaskRep<A> | undefined>;
}
export interface TaskRepResolver<A> {
    (task: Task<A>): Promise<TaskRep<A>>;
}
export declare function createDefaultTaskRepResolver<A>(delegate: OptionalTaskRepResolver<A>): TaskRepResolver<A>;
export interface CalculateOpts<A> {
    readonly potential: ReadonlyArray<Task<A>>;
    readonly resolver: TaskRepResolver<A>;
    readonly limit: number;
}
export interface TaskRep<A> extends ISpacedRep, Task<A> {
    readonly age: DurationMS;
}
